@@ -10,13 +10,15 @@ class BaseSpider(scrapy.Spider):
     ua_pc = 'Mozilla/5.0 zgrab/0.x'
     ua_mobile = 'Mozilla/5.0 (iPhone; CPU iPhone OS 15_1 like Mac OS X) By aric.zheng/0.x'
     ua_random = ua.chrome
+    support_crawling = False
 
     def get_un_crawled(self, **kwargs):
         # required:
         entity_class = kwargs.get('entity_class')
-        # optional:
+        # crawl + optional:
         crawled = kwargs.get('crawled', {'is_crawled': False})
-        options = crawled.merge(kwargs.get('options', {}))
+        crawling_opts = {'is_crawling': True} if self.support_crawling else {}
+        options = crawled.merge(kwargs.get('options', crawling_opts))
         limit = kwargs.get('limit', None)
 
         if limit:
